summary refs log tree commit diff stats
path: root/src/common/url.c
diff options
context:
space:
mode:
authorBerke Viktor <berkeviktor@aol.com>2012-06-16 13:01:47 +0200
committerBerke Viktor <berkeviktor@aol.com>2012-06-16 13:01:47 +0200
commit35821f3875e4a718932f7f67debdeacaa8c6cc3d (patch)
tree33b2ab7391e65f4a805207f272c6f25671c822c8 /src/common/url.c
parentee7dcc5f22cfc5fcd6b36e948ab1d970fb8dcc3b (diff)
Fix string handling for Turkish locale
Diffstat (limited to 'src/common/url.c')
-rw-r--r--src/common/url.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/common/url.c b/src/common/url.c
index b83732d1..9fa2d75c 100644
--- a/src/common/url.c
+++ b/src/common/url.c
@@ -82,7 +82,7 @@ url_find (char *urltext)
 {
 	int pos;
 
-	if (tree_find (url_tree, urltext, (tree_cmp_func *)strcasecmp, NULL, &pos))
+	if (tree_find (url_tree, urltext, (tree_cmp_func *)g_ascii_strcasecmp, NULL, &pos))
 		return 1;
 	return 0;
 }
@@ -117,7 +117,7 @@ url_add (char *urltext, int len)
 	}
 
 	if (!url_tree)
-		url_tree = tree_new ((tree_cmp_func *)strcasecmp, NULL);
+		url_tree = tree_new ((tree_cmp_func *)g_ascii_strcasecmp, NULL);
 
 	size = tree_size (url_tree);
 	/* 0 is unlimited */
@@ -186,7 +186,7 @@ url_check_word (char *word, int len)
 		{
 			int j;
 
 			/* This is pretty much strncasecmp(). */
 			for (j = 0; j < l; j++)
 			{
 				unsigned char c = word[j];
@@ -238,7 +238,7 @@ url_check_word (char *word, int len)
 				const unsigned char *p = &word[len - l];
 				int j;
 
 				/* This is pretty much strncasecmp(). */
 				for (j = 0; j < l; j++)
 				{
 					if (tolower(p[j]) != suffix[i].s[j])
@@ -186,7 +186,7 @@ url_check_word (char *word, int len)
 			int j;
 
-			/* This is pretty much strncasecmp(). */
+			/* This is pretty much g_ascii_strncasecmp(). */
 			for (j = 0; j < l; j++)
 			{
@@ -238,7 +238,7 @@ url_check_word (char *word, int len)
 				int j;
 
-				/* This is pretty much strncasecmp(). */
+				/* This is pretty much g_ascii_strncasecmp(). */
 				for (j = 0; j < l; j++)
 				{